'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isCurreny = exports.isIP = exports.isZipCode = exports.isQQ = exports.isChinese = exports.isEmail = exports.isUrl = exports.isPhone = exports.isMobile = exports.isCard = exports.isRequired = exports.isPassword = exports.isLetter = exports.isInt = exports.isNumber = exports.isRegex = undefined;

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _isRegex$isNumber$isC;

var _tool = require('../common/tool');

var _tool2 = _interopRequireDefault(_tool);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * 限制参数满足条件
 * @param {要判断的参数} value
 * @param {正则} regex 
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isRegex = exports.isRegex = function isRegex(value, regex, error) {
  var isRequire = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  regex = regex.test ? regex : new RegExp(regex, 'i');
  var val = typeof value != 'undefined' && value != null && ('' + value).length ? regex.test(value) ? false : error || '\u9650\u5236' + key + '\u53C2\u6570\u9700\u6EE1\u8DB3\u6B63\u5219\u8868\u8FBE\u5F0F\u8981\u6C42:' + regex : isRequire ? '\u9650\u5236' + key + '\u53C2\u6570\u4E3A\u5FC5\u586B' : false;
  if (!!val) {
    var e = new Error(val);
    e.status = 401;
    throw e;
  }
};
/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isNumber = exports.isNumber = function isNumber(value, error, isRequire) {
  return isRegex(value, /^([0-9]+\.{0,1}[0-9]{0,2})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u6570\u5B57', isRequire);
};

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isInt = exports.isInt = function isInt(value, error, isRequire) {
  return isRegex(value, /^([0-9]+)$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u6B63\u6574\u6570', isRequire);
};

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isLetter = exports.isLetter = function isLetter(value, error, isRequire) {
  return isRegex(value, /^([0-9]+)$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u6B63\u6574\u6570', isRequire);
};

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isPassword = exports.isPassword = function isPassword(value, error, isRequire) {
  return isRegex(value, /^(([a-zA-Z]|\w){5,17})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u6EE1\u8DB3\u5BC6\u7801\u8981\u6C42', isRequire);
};

/**
 * 限制参数满足是非空必填
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isRequired = exports.isRequired = function isRequired(value, error) {
  var regex = /^(\s*\S\s*)+$/g;
  var val = _tool2.default.isValid(value) ? regex.test(value) ? false : error : error;
  if (!!val) {
    var e = new Error(val);
    e.status = 401;
    throw e;
  }
};

/**
 * 限制参数满足是身份证
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isCard = exports.isCard = function isCard(value, error, isRequire) {
  return isRegex(value, /^((\d{14}|\d{17})(\d|[a-zA-Z]))$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u8EAB\u4EFD\u8BC1', isRequire);
};

/**
 * 限制参数满足是手机号
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isMobile = exports.isMobile = function isMobile(value, error, isRequire) {
  return isRegex(value, /^(1[3|4|5|6|7|8][0-9]\d{8})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u624B\u673A\u53F7', isRequire);
};

/**
 * 限制参数满足是座机
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isPhone = exports.isPhone = function isPhone(value, error, isRequire) {
  return isRegex(value, /^(\d{3}-\d{8}|\d{4}-\d{7}))$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u5EA7\u673A\u53F7', isRequire);
};

/**
 * 限制参数满足是网络地址
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isUrl = exports.isUrl = function isUrl(value, error, isRequire) {
  return isRegex(value, /^((http|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?))$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662FURL', isRequire);
};

/**
 * 限制参数满足是电子邮箱
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isEmail = exports.isEmail = function isEmail(value, error, isRequire) {
  return isRegex(value, /^(\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*)$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u90AE\u7BB1', isRequire);
};

/**
 * 限制参数满足是中文
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isChinese = exports.isChinese = function isChinese(value, error, isRequire) {
  return isRegex(value, /^([\u4e00-\u9fa5]{0,})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u4E2D\u6587', isRequire);
};

/**
 * 限制参数满足是QQ
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isQQ = exports.isQQ = function isQQ(value, error, isRequire) {
  return isRegex(value, /^([1-9]\d{4,12})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662FQQ\u53F7', isRequire);
};

/**
 * 限制参数满足是邮政编码
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isZipCode = exports.isZipCode = function isZipCode(value, error, isRequire) {
  return isRegex(value, /^([1-9]\d{5}(?!\d))$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u90AE\u7F16', isRequire);
};

/**
 * 限制参数满足是IP
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isIP = exports.isIP = function isIP(value, error, isRequire) {
  return isRegex(value, /^(([\d+\.]{3}|[\d+\.]{5})\d+)$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662FIP', isRequire);
};

/**
 * 限制参数满足是金额（2位小数）
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
var isCurreny = exports.isCurreny = function isCurreny(value, error, isRequire) {
  return isRegex(value, /^(\d+\.\d{2})$/g, error || '\u9650\u5236' + key + '\u8981\u6C42\u662F\u91D1\u989D', isRequire);
};
exports.default = (_isRegex$isNumber$isC = { isRegex: isRegex, isNumber: isNumber, isCard: isCard, isChinese: isChinese, isCurreny: isCurreny, isEmail: isEmail, isInt: isInt, isIP: isIP, isLetter: isLetter, isMobile: isMobile }, (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isNumber', isNumber), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isPassword', isPassword), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isPhone', isPhone), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isQQ', isQQ), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isRequired', isRequired), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isUrl', isUrl), (0, _defineProperty3.default)(_isRegex$isNumber$isC, 'isZipCode', isZipCode), _isRegex$isNumber$isC);
//# sourceMappingURL=regex.js.map