import V from '../common/tool';

/**
 * 限制参数满足条件
 * @param {要判断的参数} value
 * @param {正则} regex 
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isRegex = (value, regex, error, isRequire = false) => {
        regex = regex.test ? regex : new RegExp(regex, 'i');
        const val = (typeof(value) != 'undefined' && value != null && ('' + value).length) ? (regex.test(value) ? false : error || `限制${key}参数需满足正则表达式要求:${regex}`) : isRequire ? `限制${key}参数为必填` : false;
        if (!!val) {
            const e = new Error(val);
            e.status = 401;
            throw e;
        }
    }
    /**
     * 限制参数满足是数字
     * @param {要判断的值} value
     * @param {错误说明} error 
     * @param {是否必填} isRequire 
     */
export const isNumber = (value, error, isRequire) => isRegex(value, /^([0-9]+\.{0,1}[0-9]{0,2})$/g, error || `限制${key}要求是数字`, isRequire);

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isInt = (value, error, isRequire) => isRegex(value, /^([0-9]+)$/g, error || `限制${key}要求是正整数`, isRequire);

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isLetter = (value, error, isRequire) => isRegex(value, /^([0-9]+)$/g, error || `限制${key}要求是正整数`, isRequire);

/**
 * 限制参数满足是数字
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isPassword = (value, error, isRequire) => isRegex(value, /^(([a-zA-Z]|\w){5,17})$/g, error || `限制${key}要求满足密码要求`, isRequire);

/**
 * 限制参数满足是非空必填
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isRequired = (value, error) => {
    const regex = /^(\s*\S\s*)+$/g;
    const val = V.isValid(value) ? (regex.test(value) ? false : error) : error;
    if (!!val) {
        const e = new Error(val);
        e.status = 401;
        throw e;
    }
}

/**
 * 限制参数满足是身份证
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isCard = (value, error, isRequire) => isRegex(value, /^((\d{14}|\d{17})(\d|[a-zA-Z]))$/g, error || `限制${key}要求身份证`, isRequire);

/**
 * 限制参数满足是手机号
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isMobile = (value, error, isRequire) => isRegex(value, /^(1[3|4|5|6|7|8][0-9]\d{8})$/g, error || `限制${key}要求是手机号`, isRequire);

/**
 * 限制参数满足是座机
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isPhone = (value, error, isRequire) => isRegex(value, /^(\d{3}-\d{8}|\d{4}-\d{7}))$/g, error || `限制${key}要求是座机号`, isRequire);

/**
 * 限制参数满足是网络地址
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isUrl = (value, error, isRequire) => isRegex(value, /^((http|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?))$/g, error || `限制${key}要求是URL`, isRequire);

/**
 * 限制参数满足是电子邮箱
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isEmail = (value, error, isRequire) => isRegex(value, /^(\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*)$/g, error || `限制${key}要求是邮箱`, isRequire);

/**
 * 限制参数满足是中文
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isChinese = (value, error, isRequire) => isRegex(value, /^([\u4e00-\u9fa5]{0,})$/g, error || `限制${key}要求是中文`, isRequire);

/**
 * 限制参数满足是QQ
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isQQ = (value, error, isRequire) => isRegex(value, /^([1-9]\d{4,12})$/g, error || `限制${key}要求是QQ号`, isRequire);

/**
 * 限制参数满足是邮政编码
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isZipCode = (value, error, isRequire) => isRegex(value, /^([1-9]\d{5}(?!\d))$/g, error || `限制${key}要求是邮编`, isRequire);

/**
 * 限制参数满足是IP
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isIP = (value, error, isRequire) => isRegex(value, /^(([\d+\.]{3}|[\d+\.]{5})\d+)$/g, error || `限制${key}要求是IP`, isRequire);

/**
 * 限制参数满足是金额（2位小数）
 * @param {要判断的值} value
 * @param {错误说明} error 
 * @param {是否必填} isRequire 
 */
export const isCurreny = (value, error, isRequire) => isRegex(value, /^(\d+\.\d{2})$/g, error || `限制${key}要求是金额`, isRequire);
export default { isRegex, isNumber, isCard, isChinese, isCurreny, isEmail, isInt, isIP, isLetter, isMobile, isNumber, isPassword, isPhone, isQQ, isRequired, isUrl, isZipCode };